"use strict";
var ColumnTypes_1 = require("../../metadata/types/ColumnTypes");
var index_1 = require("../../index");
var ColumnMetadata_1 = require("../../metadata/ColumnMetadata");
/**
 * This column will store an update date of the updated object. This date is being updated each time you persist the
 * object.
 */
function UpdateDateColumn(options) {
    return function (object, propertyName) {
        var reflectedType = ColumnTypes_1.ColumnTypes.typeToString(Reflect.getMetadata("design:type", object, propertyName));
        // if column options are not given then create a new empty options
        if (!options)
            options = {};
        // implicitly set a type, because this column's type cannot be anything else except date
        options.type = ColumnTypes_1.ColumnTypes.DATETIME;
        // create and register a new column metadata
        index_1.defaultMetadataStorage().columnMetadatas.add(new ColumnMetadata_1.ColumnMetadata({
            target: object.constructor,
            propertyName: propertyName,
            propertyType: reflectedType,
            mode: "updateDate",
            options: options
        }));
    };
}
exports.UpdateDateColumn = UpdateDateColumn;
//# sourceMappingURL=UpdateDateColumn.js.map