"use strict";
var RelationMetadata_1 = require("../../metadata/RelationMetadata");
var RelationTypes_1 = require("../../metadata/types/RelationTypes");
var index_1 = require("../../index");
/**
 * Many-to-many is a type of relationship when Entity1 can have multiple instances of Entity2, and Entity2 can have
 * multiple instances of Entity1. To achieve it, this type of relation creates a junction table, where it storage
 * entity1 and entity2 ids. This is owner side of the relationship.
 */
function ManyToMany(typeFunction, inverseSideOrOptions, options) {
    var inverseSideProperty;
    if (typeof inverseSideOrOptions === "object") {
        options = inverseSideOrOptions;
    }
    else {
        inverseSideProperty = inverseSideOrOptions;
    }
    return function (object, propertyName) {
        if (!options)
            options = {};
        var reflectedType = Reflect.getMetadata("design:type", object, propertyName);
        index_1.defaultMetadataStorage().relationMetadatas.add(new RelationMetadata_1.RelationMetadata({
            target: object.constructor,
            propertyName: propertyName,
            propertyType: reflectedType,
            relationType: RelationTypes_1.RelationTypes.MANY_TO_MANY,
            type: typeFunction,
            inverseSideProperty: inverseSideProperty,
            options: options
        }));
    };
}
exports.ManyToMany = ManyToMany;
//# sourceMappingURL=ManyToMany.js.map