"use strict";
var RelationMetadata_1 = require("../../metadata/RelationMetadata");
var RelationTypes_1 = require("../../metadata/types/RelationTypes");
var index_1 = require("../../index");
/**
 * Many-to-one relation allows to create type of relation when Entity1 can have single instance of Entity2, but
 * Entity2 can have a multiple instances of Entity1. Entity1 is an owner of the relationship, and storages Entity2 id
 * on its own side.
 */
function ManyToOne(typeFunction, inverseSideOrOptions, options) {
    var inverseSideProperty;
    if (typeof inverseSideOrOptions === "object") {
        options = inverseSideOrOptions;
    }
    else {
        inverseSideProperty = inverseSideOrOptions;
    }
    return function (object, propertyName) {
        if (!options)
            options = {};
        var reflectedType = Reflect.getMetadata("design:type", object, propertyName);
        index_1.defaultMetadataStorage().relationMetadatas.add(new RelationMetadata_1.RelationMetadata({
            target: object.constructor,
            propertyName: propertyName,
            propertyType: reflectedType,
            relationType: RelationTypes_1.RelationTypes.MANY_TO_ONE,
            type: typeFunction,
            inverseSideProperty: inverseSideProperty,
            options: options
        }));
    };
}
exports.ManyToOne = ManyToOne;
//# sourceMappingURL=ManyToOne.js.map