"use strict";
var RelationMetadata_1 = require("../../metadata/RelationMetadata");
var RelationTypes_1 = require("../../metadata/types/RelationTypes");
var index_1 = require("../../index");
/**
 * One-to-one relation allows to create direct relation between two entities. Entity1 have only one Entity2.
 * Entity1 is an owner of the relationship, and storages Entity1 id on its own side.
 */
function OneToOne(typeFunction, inverseSideOrOptions, options) {
    var inverseSideProperty;
    if (typeof inverseSideOrOptions === "object") {
        options = inverseSideOrOptions;
    }
    else {
        inverseSideProperty = inverseSideOrOptions;
    }
    return function (object, propertyName) {
        if (!options)
            options = {};
        var reflectedType = Reflect.getMetadata("design:type", object, propertyName);
        index_1.defaultMetadataStorage().relationMetadatas.add(new RelationMetadata_1.RelationMetadata({
            target: object.constructor,
            propertyName: propertyName,
            propertyType: reflectedType,
            relationType: RelationTypes_1.RelationTypes.ONE_TO_ONE,
            type: typeFunction,
            inverseSideProperty: inverseSideProperty,
            options: options
        }));
    };
}
exports.OneToOne = OneToOne;
//# sourceMappingURL=OneToOne.js.map