"use strict";
/**
 * Provides base functionality for all driver implementations.
 */
var BaseDriver = (function () {
    function BaseDriver() {
    }
    // -------------------------------------------------------------------------
    // Protected Methods
    // -------------------------------------------------------------------------
    BaseDriver.prototype.logQuery = function (query) {
        if (this.connectionOptions.logging && this.connectionOptions.logging.logQueries)
            this.log("executing query: " + query, "log");
    };
    BaseDriver.prototype.logQueryError = function (error) {
        if (this.connectionOptions.logging && this.connectionOptions.logging.logFailedQueryError) {
            this.log("error during executing query:", "error");
            this.log(error, "error");
        }
    };
    BaseDriver.prototype.logFailedQuery = function (query) {
        if (this.connectionOptions.logging &&
            (this.connectionOptions.logging.logQueries || this.connectionOptions.logging.logOnlyFailedQueries))
            this.log("query failed: " + query, "error");
    };
    BaseDriver.prototype.log = function (message, level) {
        if (!this.connectionOptions.logging)
            return;
        if (this.connectionOptions && this.connectionOptions.logging && this.connectionOptions.logging.logger) {
            this.connectionOptions.logging.logger(message, level);
        }
        else {
            switch (level) {
                case "log":
                    console.log(message);
                    break;
                case "debug":
                    console.debug(message);
                    break;
                case "info":
                    console.info(message);
                    break;
                case "error":
                    console.error(message);
                    break;
            }
        }
    };
    return BaseDriver;
}());
exports.BaseDriver = BaseDriver;
//# sourceMappingURL=BaseDriver.js.map