/*!
 
 */
"use strict";
var ConnectionManager_1 = require("./connection-manager/ConnectionManager");
var MetadataStorage_1 = require("./metadata-storage/MetadataStorage");
// -------------------------------------------------------------------------
// Global Container
// -------------------------------------------------------------------------
/**
 * Container to be used by TypeORM for inversion control.
 */
var container;
/**
 * Sets container to be used by TypeORM.
 *
 * @param iocContainer
 */
function useContainer(iocContainer) {
    container = iocContainer;
}
exports.useContainer = useContainer;
function getContainer() {
    return container;
}
exports.getContainer = getContainer;
// -------------------------------------------------------------------------
// Global Metadata Storage
// -------------------------------------------------------------------------
/**
 * Default metadata storage used as singleton and can be used to storage all metadatas in the system.
 */
var metadataStorage;
function defaultMetadataStorage() {
    if (!metadataStorage && container) {
        metadataStorage = container.get(MetadataStorage_1.MetadataStorage);
    }
    else if (!metadataStorage) {
        metadataStorage = new MetadataStorage_1.MetadataStorage();
    }
    return metadataStorage;
}
exports.defaultMetadataStorage = defaultMetadataStorage;
// -------------------------------------------------------------------------
// Global Connection Manager
// -------------------------------------------------------------------------
/**
 * Default export. Global connection manager.
 */
var connectionManager;
/**
 * Gets a ConnectionManager which creates connections.
 */
function getConnectionManager() {
    if (!connectionManager && container) {
        connectionManager = container.get(ConnectionManager_1.ConnectionManager);
    }
    else if (!connectionManager) {
        connectionManager = new ConnectionManager_1.ConnectionManager();
    }
    return connectionManager;
}
exports.getConnectionManager = getConnectionManager;
/**
 * Allows to quickly create a connection based on the given options. Uses ConnectionManager.
 */
function createConnection(options) {
    return getConnectionManager().create(options);
}
exports.createConnection = createConnection;
// -------------------------------------------------------------------------
// Commonly Used exports
// -------------------------------------------------------------------------
var Connection_1 = require("./connection/Connection");
exports.Connection = Connection_1.Connection;
var ConnectionManager_2 = require("./connection-manager/ConnectionManager");
exports.ConnectionManager = ConnectionManager_2.ConnectionManager;
var MysqlDriver_1 = require("./driver/MysqlDriver");
exports.MysqlDriver = MysqlDriver_1.MysqlDriver;
var QueryBuilder_1 = require("./query-builder/QueryBuilder");
exports.QueryBuilder = QueryBuilder_1.QueryBuilder;
var EntityManager_1 = require("./entity-manager/EntityManager");
exports.EntityManager = EntityManager_1.EntityManager;
var Repository_1 = require("./repository/Repository");
exports.Repository = Repository_1.Repository;
//# sourceMappingURL=index.js.map