import { PropertyMetadata } from "./PropertyMetadata";
import { NamingStrategyInterface } from "../naming-strategy/NamingStrategyInterface";
import { ColumnMetadataArgs } from "./args/ColumnMetadataArgs";
import { ColumnType } from "./types/ColumnTypes";
export declare type ColumnMode = "regular" | "createDate" | "updateDate" | "version" | "treeChildrenCount" | "treeLevel";
/**
 * This metadata contains all information about class's column.
 */
export declare class ColumnMetadata extends PropertyMetadata {
    /**
     * Naming strategy to be used to generate column name.
     */
    namingStrategy: NamingStrategyInterface;
    /**
     * The real reflected property type.
     */
    readonly propertyType: string;
    /**
     * The type of the column.
     */
    readonly type: ColumnType;
    /**
     * The mode of the column.
     */
    readonly mode: ColumnMode;
    /**
     * Maximum length in the database.
     */
    readonly length: string;
    /**
     * Indicates if this column is primary key.
     */
    readonly isPrimary: boolean;
    /**
     * Indicates if this column is auto increment.
     */
    readonly isAutoIncrement: boolean;
    /**
     * Indicates if value should be unique or not.
     */
    readonly isUnique: boolean;
    /**
     * Indicates if can contain nulls or not.
     */
    readonly isNullable: boolean;
    /**
     * Indicates if column is virtual. Virtual columns are not mapped to the entity.
     */
    readonly isVirtual: boolean;
    /**
     * Extra sql definition for the given column.
     */
    readonly columnDefinition: string;
    /**
     * Column comment.
     */
    readonly comment: string;
    /**
     * Old column name. Used to correctly alter tables when column name is changed.
     */
    readonly oldColumnName: string;
    /**
     * The precision for a decimal (exact numeric) column (applies only for decimal column), which is the maximum
     * number of digits that are stored for the values.
     */
    readonly precision: number;
    /**
     * The scale for a decimal (exact numeric) column (applies only for decimal column), which represents the number
     * of digits to the right of the decimal point and must not be greater than precision.
     */
    readonly scale: number;
    /**
     * Column collation. Note that not all databases support it.
     */
    readonly collation: string;
    /**
     * Column name to be used in the database.
     */
    private _name;
    constructor(args: ColumnMetadataArgs);
    /**
     * Column name in the database.
     */
    readonly name: string;
    readonly isUpdateDate: boolean;
    readonly isCreateDate: boolean;
    readonly isVersion: boolean;
}
