"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var PropertyMetadata_1 = require("./PropertyMetadata");
/**
 * This metadata contains all information about class's column.
 */
var ColumnMetadata = (function (_super) {
    __extends(ColumnMetadata, _super);
    // ---------------------------------------------------------------------
    // Constructor
    // ---------------------------------------------------------------------
    function ColumnMetadata(args) {
        _super.call(this, args.target, args.propertyName);
        /**
         * Maximum length in the database.
         */
        this.length = "";
        /**
         * Indicates if this column is primary key.
         */
        this.isPrimary = false;
        /**
         * Indicates if this column is auto increment.
         */
        this.isAutoIncrement = false;
        /**
         * Indicates if value should be unique or not.
         */
        this.isUnique = false;
        /**
         * Indicates if can contain nulls or not.
         */
        this.isNullable = false;
        /**
         * Indicates if column is virtual. Virtual columns are not mapped to the entity.
         */
        this.isVirtual = false;
        /**
         * Extra sql definition for the given column.
         */
        this.columnDefinition = "";
        /**
         * Column comment.
         */
        this.comment = "";
        if (args.isPrimaryKey)
            this.isPrimary = args.isPrimaryKey;
        if (args.mode)
            this.mode = args.mode;
        if (args.isVirtual)
            this.isVirtual = args.isVirtual;
        if (args.propertyType)
            this.propertyType = args.propertyType.toLowerCase();
        if (args.options.name)
            this._name = args.options.name;
        if (args.options.type)
            this.type = args.options.type;
        if (args.options.length)
            this.length = args.options.length;
        if (args.options.generated)
            this.isAutoIncrement = args.options.generated;
        if (args.options.unique)
            this.isUnique = args.options.unique;
        if (args.options.nullable)
            this.isNullable = args.options.nullable;
        if (args.options.columnDefinition)
            this.columnDefinition = args.options.columnDefinition;
        if (args.options.comment)
            this.comment = args.options.comment;
        if (args.options.oldColumnName)
            this.oldColumnName = args.options.oldColumnName;
        if (args.options.scale)
            this.scale = args.options.scale;
        if (args.options.precision)
            this.precision = args.options.precision;
        if (args.options.collation)
            this.collation = args.options.collation;
    }
    Object.defineProperty(ColumnMetadata.prototype, "name", {
        // ---------------------------------------------------------------------
        // Accessors
        // ---------------------------------------------------------------------
        /**
         * Column name in the database.
         */
        get: function () {
            if (this._name)
                return this._name;
            return this.namingStrategy ? this.namingStrategy.columnName(this.propertyName) : this.propertyName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "isUpdateDate", {
        get: function () {
            return this.mode === "updateDate";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "isCreateDate", {
        get: function () {
            return this.mode === "createDate";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ColumnMetadata.prototype, "isVersion", {
        get: function () {
            return this.mode === "version";
        },
        enumerable: true,
        configurable: true
    });
    return ColumnMetadata;
}(PropertyMetadata_1.PropertyMetadata));
exports.ColumnMetadata = ColumnMetadata;
//# sourceMappingURL=ColumnMetadata.js.map