import { TableMetadata } from "./TableMetadata";
import { ColumnMetadata } from "./ColumnMetadata";
import { RelationMetadata } from "./RelationMetadata";
import { CompositeIndexMetadata } from "./CompositeIndexMetadata";
import { ForeignKeyMetadata } from "./ForeignKeyMetadata";
import { NamingStrategyInterface } from "../naming-strategy/NamingStrategyInterface";
/**
 * Contains all entity metadata.
 */
export declare class EntityMetadata {
    closureJunctionTable: EntityMetadata;
    /**
     * Naming strategy used to generate and normalize column name.
     */
    readonly namingStrategy: NamingStrategyInterface;
    readonly table: TableMetadata;
    readonly columns: ColumnMetadata[];
    readonly relations: RelationMetadata[];
    readonly compositeIndices: CompositeIndexMetadata[];
    readonly foreignKeys: ForeignKeyMetadata[];
    constructor(namingStrategy: NamingStrategyInterface, tableMetadata: TableMetadata, columnMetadatas: ColumnMetadata[], relationMetadatas: RelationMetadata[], compositeIndexMetadatas: CompositeIndexMetadata[]);
    readonly name: string;
    readonly target: Function;
    readonly oneToOneRelations: RelationMetadata[];
    readonly ownerOneToOneRelations: RelationMetadata[];
    readonly oneToManyRelations: RelationMetadata[];
    readonly manyToOneRelations: RelationMetadata[];
    readonly manyToManyRelations: RelationMetadata[];
    readonly ownerManyToManyRelations: RelationMetadata[];
    readonly relationsWithJoinColumns: RelationMetadata[];
    readonly hasPrimaryColumn: boolean;
    readonly primaryColumn: ColumnMetadata;
    readonly hasCreateDateColumn: boolean;
    readonly createDateColumn: ColumnMetadata;
    readonly hasUpdateDateColumn: boolean;
    readonly updateDateColumn: ColumnMetadata;
    readonly hasVersionColumn: boolean;
    readonly versionColumn: ColumnMetadata;
    readonly hasTreeChildrenCountColumn: boolean;
    readonly treeChildrenCountColumn: ColumnMetadata;
    readonly hasTreeLevelColumn: boolean;
    readonly treeLevelColumn: ColumnMetadata;
    readonly hasPrimaryKey: boolean;
    /**
     * Creates a new entity.
     */
    create(): any;
    createPropertiesMap(): any;
    getEntityId(entity: any): any;
    hasColumnWithPropertyName(propertyName: string): boolean;
    hasColumnWithDbName(name: string): boolean;
    hasRelationWithPropertyName(propertyName: string): boolean;
    findRelationWithPropertyName(propertyName: string): RelationMetadata;
    hasRelationWithDbName(dbName: string): boolean;
    findRelationWithDbName(propertyName: string): RelationMetadata;
    hasRelationWithOneWithPropertyName(propertyName: string): boolean;
    findRelationWithOneWithPropertyName(propertyName: string): RelationMetadata;
    hasRelationWithOneWithDbName(name: string): boolean;
    findRelationWithOneWithDbName(name: string): RelationMetadata;
    hasRelationWithManyWithPropertyName(name: string): boolean;
    findRelationWithManyWithPropertyName(name: string): RelationMetadata;
    hasRelationWithManyWithDbName(name: string): boolean;
    findRelationWithManyWithDbName(name: string): RelationMetadata;
    readonly hasTreeParentRelation: boolean;
    readonly treeParentRelation: RelationMetadata;
    readonly hasTreeChildrenRelation: boolean;
    readonly treeChildrenRelation: RelationMetadata;
}
