import { ColumnMetadata } from "./ColumnMetadata";
import { TableMetadata } from "./TableMetadata";
export declare type OnDeleteType = "RESTRICT" | "CASCADE" | "SET NULL";
/**
 * This metadata interface contains all information foreign keys.
 */
export declare class ForeignKeyMetadata {
    /**
     * Table to which this foreign key is applied.
     */
    readonly table: TableMetadata;
    /**
     * Array of columns.
     */
    readonly columns: ColumnMetadata[];
    /**
     * Table to which this foreign key is references.
     */
    readonly referencedTable: TableMetadata;
    /**
     * Array of referenced columns.
     */
    readonly referencedColumns: ColumnMetadata[];
    /**
     * What to do with a relation on deletion of the row containing a foreign key.
     */
    readonly onDelete: OnDeleteType;
    constructor(table: TableMetadata, columns: ColumnMetadata[], referencedTable: TableMetadata, referencedColumns: ColumnMetadata[], onDelete?: OnDeleteType);
    /**
     * Array of column names.
     */
    readonly columnNames: string[];
    /**
     * Array of referenced column names.
     */
    readonly referencedColumnNames: string[];
    /**
     * Foreign key name.
     */
    readonly name: string;
}
