"use strict";
/**
 * This metadata interface contains all information foreign keys.
 */
var ForeignKeyMetadata = (function () {
    // -------------------------------------------------------------------------
    // Constructor
    // -------------------------------------------------------------------------
    function ForeignKeyMetadata(table, columns, referencedTable, referencedColumns, onDelete) {
        this.table = table;
        this.columns = columns;
        this.referencedTable = referencedTable;
        this.referencedColumns = referencedColumns;
        if (onDelete)
            this.onDelete = onDelete;
    }
    Object.defineProperty(ForeignKeyMetadata.prototype, "columnNames", {
        // -------------------------------------------------------------------------
        // Accessors
        // -------------------------------------------------------------------------
        /**
         * Array of column names.
         */
        get: function () {
            return this.columns.map(function (column) { return column.name; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ForeignKeyMetadata.prototype, "referencedColumnNames", {
        /**
         * Array of referenced column names.
         */
        get: function () {
            return this.referencedColumns.map(function (column) { return column.name; });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ForeignKeyMetadata.prototype, "name", {
        /**
         * Foreign key name.
         */
        get: function () {
            // todo: use naming strategy
            var key = (this.table.name + "_" + this.columnNames.join("_")) +
                ("_" + this.referencedTable.name + "_" + this.referencedColumnNames.join("_"));
            return "fk_" + require("sha1")(key); // todo: use crypto instead?
        },
        enumerable: true,
        configurable: true
    });
    return ForeignKeyMetadata;
}());
exports.ForeignKeyMetadata = ForeignKeyMetadata;
//# sourceMappingURL=ForeignKeyMetadata.js.map