"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var PropertyMetadata_1 = require("./PropertyMetadata");
var RelationTypes_1 = require("./types/RelationTypes");
/**
 * This metadata interface contains all information about some document's relation.
 */
var RelationMetadata = (function (_super) {
    __extends(RelationMetadata, _super);
    // ---------------------------------------------------------------------
    // Constructor
    // ---------------------------------------------------------------------
    function RelationMetadata(args) {
        _super.call(this, args.target, args.propertyName);
        // ---------------------------------------------------------------------
        // Readonly Properties
        // ---------------------------------------------------------------------
        /**
         * Indicates if this is a parent (can be only many-to-one relation) relation in the tree tables.
         */
        this.isTreeParent = false;
        /**
         * Indicates if this is a children (can be only one-to-many relation) relation in the tree tables.
         */
        this.isTreeChildren = false;
        /**
         * Indicates if relation column value can be nullable or not.
         */
        this.isNullable = true;
        this.relationType = args.relationType;
        if (args.inverseSideProperty)
            this._inverseSideProperty = args.inverseSideProperty;
        if (args.options.name)
            this._name = args.options.name;
        if (args.propertyType)
            this.propertyType = args.propertyType;
        if (args.options.cascadeInsert || args.options.cascadeAll)
            this.isCascadeInsert = true;
        if (args.options.cascadeUpdate || args.options.cascadeAll)
            this.isCascadeUpdate = true;
        if (args.options.cascadeRemove || args.options.cascadeAll)
            this.isCascadeRemove = true;
        if (args.options.oldColumnName)
            this.oldColumnName = args.options.oldColumnName;
        if (args.options.nullable)
            this.isNullable = args.options.nullable;
        if (args.options.onDelete)
            this.onDelete = args.options.onDelete;
        if (args.isTreeParent)
            this.isTreeParent = true;
        if (args.isTreeChildren)
            this.isTreeChildren = true;
        if (!this._type)
            this._type = args.type;
        if (!this._name)
            this._name = args.propertyName;
    }
    Object.defineProperty(RelationMetadata.prototype, "name", {
        // ---------------------------------------------------------------------
        // Accessors
        // ---------------------------------------------------------------------
        get: function () {
            if (this.joinColumn && this.joinColumn.name)
                return this.joinColumn.name;
            return this.namingStrategy ? this.namingStrategy.relationName(this._name) : this._name;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "referencedColumnName", {
        get: function () {
            if (this.joinColumn && this.joinColumn.referencedColumn && this.joinColumn.referencedColumn.name)
                return this.joinColumn.referencedColumn.name;
            return this.inverseEntityMetadata.primaryColumn.propertyName;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isOwning", {
        /**
         * Indicates if this side is an owner of this relation.
         */
        get: function () {
            return this.isManyToOne ||
                (this.isManyToMany && this.joinTable) ||
                (this.isOneToOne && this.joinColumn);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "type", {
        get: function () {
            return this._type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "inverseSideProperty", {
        get: function () {
            if (this._inverseSideProperty) {
                return this.computeInverseSide(this._inverseSideProperty);
            }
            else if (this.isTreeParent) {
                return this.entityMetadata.treeChildrenRelation.propertyName;
            }
            else if (this.isTreeChildren) {
                return this.entityMetadata.treeParentRelation.propertyName;
            }
            return "";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "inverseRelation", {
        get: function () {
            var relation = this.inverseEntityMetadata.findRelationWithPropertyName(this.inverseSideProperty);
            if (!relation)
                throw new Error("Inverse side was not found in the relation " + this.entityMetadata.name + "#" + this.inverseSideProperty);
            return relation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isOneToOne", {
        get: function () {
            return this.relationType === RelationTypes_1.RelationTypes.ONE_TO_ONE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isOneToMany", {
        get: function () {
            return this.relationType === RelationTypes_1.RelationTypes.ONE_TO_MANY;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isManyToOne", {
        get: function () {
            return this.relationType === RelationTypes_1.RelationTypes.MANY_TO_ONE;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isManyToMany", {
        get: function () {
            return this.relationType === RelationTypes_1.RelationTypes.MANY_TO_MANY;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "hasInverseSide", {
        get: function () {
            return this.inverseEntityMetadata && this.inverseEntityMetadata.hasRelationWithPropertyName(this.inverseSideProperty);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(RelationMetadata.prototype, "isLazy", {
        get: function () {
            return this.propertyType && this.propertyType.name && this.propertyType.name.toLowerCase() === "promise";
        },
        enumerable: true,
        configurable: true
    });
    // ---------------------------------------------------------------------
    // Private Methods
    // ---------------------------------------------------------------------
    RelationMetadata.prototype.computeInverseSide = function (inverseSide) {
        var ownerEntityPropertiesMap = this.inverseEntityMetadata.createPropertiesMap();
        if (typeof inverseSide === "function")
            return inverseSide(ownerEntityPropertiesMap);
        if (typeof inverseSide === "string")
            return inverseSide;
        // throw new Error("Cannot compute inverse side of the relation");
        return "";
    };
    return RelationMetadata;
}(PropertyMetadata_1.PropertyMetadata));
exports.RelationMetadata = RelationMetadata;
//# sourceMappingURL=RelationMetadata.js.map