import { TargetMetadata } from "./TargetMetadata";
import { EntityMetadata } from "./EntityMetadata";
/**
 * Table type.
 */
export declare type TableType = "regular" | "abstract" | "junction" | "closure" | "closureJunction";
/**
 * This metadata interface contains all information about specific table.
 */
export declare class TableMetadata extends TargetMetadata {
    /**
     * Naming strategy used to generate and normalize table name.
     */
    entityMetadata: EntityMetadata;
    /**
     * Indicates if this table is abstract or not. Regular tables can inherit columns from abstract tables.
     */
    private readonly tableType;
    /**
     * Table name in the database.
     */
    private readonly _name;
    constructor(target?: Function, name?: string, type?: TableType);
    /**
     * Checks if this table is abstract.
     */
    readonly isAbstract: boolean;
    /**
     * Checks if this table is regular (non abstract and non closure).
     */
    readonly isRegular: boolean;
    /**
     * Checks if this table is a closure table.
     */
    readonly isClosure: boolean;
    /**
     * Table name in the database.
     */
    readonly name: string;
    /**
     * Checks if this table is inherited from another table.
     */
    isInherited(anotherTable: TableMetadata): boolean;
}
