"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var TargetMetadata_1 = require("./TargetMetadata");
/**
 * This metadata interface contains all information about specific table.
 */
var TableMetadata = (function (_super) {
    __extends(TableMetadata, _super);
    // ---------------------------------------------------------------------
    // Constructor
    // ---------------------------------------------------------------------
    function TableMetadata(target, name, type) {
        if (type === void 0) { type = "regular"; }
        _super.call(this, target);
        if (name)
            this._name = name;
        if (type)
            this.tableType = type;
    }
    Object.defineProperty(TableMetadata.prototype, "isAbstract", {
        // ---------------------------------------------------------------------
        // Accessors
        // ---------------------------------------------------------------------
        /**
         * Checks if this table is abstract.
         */
        get: function () {
            return this.tableType === "abstract";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableMetadata.prototype, "isRegular", {
        /**
         * Checks if this table is regular (non abstract and non closure).
         */
        get: function () {
            return this.tableType === "regular";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableMetadata.prototype, "isClosure", {
        /**
         * Checks if this table is a closure table.
         */
        get: function () {
            return this.tableType === "closure";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TableMetadata.prototype, "name", {
        /**
         * Table name in the database.
         */
        get: function () {
            if (this._name)
                return this._name;
            return this.entityMetadata.namingStrategy.tableName(this.target.name);
        },
        enumerable: true,
        configurable: true
    });
    // ---------------------------------------------------------------------
    // Public Methods
    // ---------------------------------------------------------------------
    /**
     * Checks if this table is inherited from another table.
     */
    TableMetadata.prototype.isInherited = function (anotherTable) {
        return Object.getPrototypeOf(this.target.prototype).constructor === anotherTable.target;
        // we cannot use instanceOf in this method, because we need order of inherited tables, to ensure that
        // properties get inherited in a right order. To achieve it we can only check a first parent of the class
        // return this.target.prototype instanceof anotherTable.target;
    };
    return TableMetadata;
}(TargetMetadata_1.TargetMetadata));
exports.TableMetadata = TableMetadata;
//# sourceMappingURL=TableMetadata.js.map