"use strict";
var _ = require("lodash");
/**
 * Naming strategy that is used by default.
 */
var DefaultNamingStrategy = (function () {
    function DefaultNamingStrategy() {
    }
    DefaultNamingStrategy.prototype.tableName = function (className) {
        return _.snakeCase(className);
    };
    DefaultNamingStrategy.prototype.columnName = function (propertyName) {
        return propertyName;
    };
    DefaultNamingStrategy.prototype.relationName = function (propertyName) {
        return propertyName;
    };
    DefaultNamingStrategy.prototype.indexName = function (target, name, columns) {
        if (name)
            return name;
        return "ind_" + columns.join("_");
    };
    DefaultNamingStrategy.prototype.joinColumnInverseSideName = function (joinColumnName, propertyName) {
        if (joinColumnName)
            return joinColumnName;
        return propertyName;
    };
    DefaultNamingStrategy.prototype.joinTableName = function (firstTableName, secondTableName, firstColumnName, secondColumnName, firstPropertyName, secondPropertyName) {
        return _.snakeCase(firstTableName + "_" + firstColumnName + "_" + secondTableName + "_" + secondPropertyName);
    };
    DefaultNamingStrategy.prototype.joinTableColumnName = function (tableName, columnName, secondTableName, secondColumnName) {
        var column1 = tableName + "_" + columnName;
        var column2 = secondTableName + "_" + secondColumnName;
        return column1 === column2 ? column1 + "_1" : column1;
    };
    DefaultNamingStrategy.prototype.joinTableInverseColumnName = function (tableName, columnName, secondTableName, secondColumnName) {
        var column1 = tableName + "_" + columnName;
        var column2 = secondTableName + "_" + secondColumnName;
        return column1 === column2 ? column1 + "_2" : column1;
    };
    DefaultNamingStrategy.prototype.closureJunctionTableName = function (tableName) {
        return tableName + "_closure";
    };
    return DefaultNamingStrategy;
}());
exports.DefaultNamingStrategy = DefaultNamingStrategy;
//# sourceMappingURL=DefaultNamingStrategy.js.map