import { Broadcaster } from "../subscriber/Broadcaster";
import { EntityMetadataCollection } from "../metadata/collection/EntityMetadataCollection";
import { Driver } from "../driver/Driver";
export declare class QueryBuilder<Entity> {
    private driver;
    private entityMetadatas;
    private broadcaster;
    private aliasMap;
    private type;
    private selects;
    private fromEntity;
    private fromTableName;
    private fromTableAlias;
    private updateQuerySet;
    private joins;
    private groupBys;
    private wheres;
    private havings;
    private orderBys;
    private parameters;
    private limit;
    private offset;
    private firstResult;
    private maxResults;
    constructor(driver: Driver, entityMetadatas: EntityMetadataCollection, broadcaster: Broadcaster);
    readonly alias: string;
    delete(entity?: Function): this;
    delete(tableName?: string): this;
    update(updateSet: Object): this;
    update(entity: Function, updateSet: Object): this;
    update(tableName: string, updateSet: Object): this;
    select(selection?: string): this;
    select(selection?: string[]): this;
    select(...selection: string[]): this;
    addSelect(selection: string): this;
    addSelect(selection: string[]): this;
    addSelect(...selection: string[]): this;
    from(tableName: string, alias: string): this;
    from(entity: Function, alias: string): this;
    innerJoinAndMapMany(mapToProperty: string, property: string, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    innerJoinAndMapMany(mapToProperty: string, entity: Function, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    innerJoinAndMapOne(mapToProperty: string, property: string, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    innerJoinAndMapOne(mapToProperty: string, entity: Function, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    innerJoinAndSelect(property: string, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    innerJoinAndSelect(entity: Function, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    innerJoin(property: string, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    innerJoin(entity: Function, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    leftJoinAndMapMany(mapToProperty: string, property: string, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    leftJoinAndMapMany(mapToProperty: string, entity: Function, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    leftJoinAndMapOne(mapToProperty: string, property: string, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    leftJoinAndMapOne(mapToProperty: string, entity: Function, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    leftJoinAndSelect(property: string, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    leftJoinAndSelect(entity: Function, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    leftJoin(property: string, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    leftJoin(entity: Function, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }): this;
    where(where: string, parameters?: {
        [key: string]: any;
    }): this;
    andWhere(where: string, parameters?: {
        [key: string]: any;
    }): this;
    orWhere(where: string, parameters?: {
        [key: string]: any;
    }): this;
    groupBy(groupBy: string): this;
    addGroupBy(groupBy: string): this;
    having(having: string, parameters?: {
        [key: string]: any;
    }): this;
    andHaving(having: string, parameters?: {
        [key: string]: any;
    }): this;
    orHaving(having: string, parameters?: {
        [key: string]: any;
    }): this;
    orderBy(sort: string, order?: "ASC" | "DESC"): this;
    addOrderBy(sort: string, order?: "ASC" | "DESC"): this;
    setLimit(limit: number): this;
    setOffset(offset: number): this;
    setFirstResult(firstResult: number): this;
    setMaxResults(maxResults: number): this;
    setParameter(key: string, value: any): this;
    setParameters(parameters: {
        [key: string]: any;
    }): this;
    addParameters(parameters: {
        [key: string]: any;
    }): this;
    getSql(): string;
    execute(): Promise<any>;
    getScalarResults<T>(): Promise<T[]>;
    getSingleScalarResult<T>(): Promise<T>;
    getResults(): Promise<Entity[]>;
    getResultsAndScalarResults(): Promise<{
        entities: Entity[];
        scalarResults: any[];
    }>;
    getSingleResult(): Promise<Entity>;
    getCount(): Promise<number>;
    getResultsAndCount(): Promise<[Entity[], number]>;
    clone(options?: {
        skipOrderBys?: boolean;
        skipLimit?: boolean;
        skipOffset?: boolean;
    }): QueryBuilder<{}>;
    protected rawResultsToEntities(results: any[]): any[];
    protected addLazyProperties(entities: any[]): any[];
    protected createSelectExpression(): string;
    protected createWhereExpression(): string;
    protected createJoinExpression(): string;
    protected createGroupByExpression(): string;
    protected createHavingExpression(): string;
    protected createOrderByExpression(): string;
    protected createLimitExpression(): string;
    protected createOffsetExpression(): string;
    protected replaceParameters(sql: string): string;
    private extractJoinMappings();
    protected join(joinType: "INNER" | "LEFT", property: string, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }, mapToProperty?: string, isMappingMany?: boolean): this;
    protected join(joinType: "INNER" | "LEFT", entity: Function, alias: string, conditionType?: "ON" | "WITH", condition?: string, parameters?: {
        [key: string]: any;
    }, mapToProperty?: string, isMappingMany?: boolean): this;
    protected join(joinType: "INNER" | "LEFT", entityOrProperty: Function | string, alias: string, conditionType: "ON" | "WITH", condition: string, parameters?: {
        [key: string]: any;
    }, mapToProperty?: string, isMappingMany?: boolean): this;
}
