"use strict";
/**
 * Transforms plain old javascript object
 * Entity is constructed based on its entity metadata.
 *
 * @internal
 */
var PlainObjectToNewEntityTransformer = (function () {
    // -------------------------------------------------------------------------
    // Constructor
    // -------------------------------------------------------------------------
    function PlainObjectToNewEntityTransformer() {
    }
    // -------------------------------------------------------------------------
    // Public Methods
    // -------------------------------------------------------------------------
    PlainObjectToNewEntityTransformer.prototype.transform = function (object, metadata) {
        return this.groupAndTransform(object, metadata);
    };
    // -------------------------------------------------------------------------
    // Private Methods
    // -------------------------------------------------------------------------
    /**
     * Since db returns a duplicated rows of the data where accuracies of the same object can be duplicated
     * we need to group our result and we must have some unique id (primary key in our case)
     */
    PlainObjectToNewEntityTransformer.prototype.groupAndTransform = function (object, metadata) {
        var _this = this;
        var entity = metadata.create();
        // copy regular column properties from the given object
        metadata.columns
            .filter(function (column) { return object.hasOwnProperty(column.propertyName); })
            .forEach(function (column) { return entity[column.propertyName] = object[column.propertyName]; }); // todo: also need to be sure that type is correct
        // if relation is loaded then go into it recursively and transform its values too
        metadata.relations
            .filter(function (relation) { return object.hasOwnProperty(relation.propertyName); })
            .forEach(function (relation) {
            var relationMetadata = relation.inverseEntityMetadata;
            if (!relationMetadata)
                throw new Error("Relation metadata for the relation " + metadata.target.name + "#" + relation.propertyName + " is missing");
            if (relation.isManyToMany || relation.isOneToMany) {
                if (object[relation.propertyName] instanceof Array) {
                    entity[relation.propertyName] = object[relation.propertyName].map(function (subObject) {
                        return _this.groupAndTransform(subObject, relationMetadata);
                    });
                }
                else {
                    entity[relation.propertyName] = object[relation.propertyName];
                }
            }
            else {
                if (object[relation.propertyName]) {
                    entity[relation.propertyName] = _this.groupAndTransform(object[relation.propertyName], relationMetadata);
                }
                else {
                    entity[relation.propertyName] = object[relation.propertyName];
                }
            }
        });
        return entity;
    };
    return PlainObjectToNewEntityTransformer;
}());
exports.PlainObjectToNewEntityTransformer = PlainObjectToNewEntityTransformer;
//# sourceMappingURL=PlainObjectToNewEntityTransformer.js.map