"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var ReactiveRepository_1 = require("./ReactiveRepository");
/**
 * Tree repository is supposed to work with your entity objects. Find entities, insert, update, delete, etc.
 * This version of TreeRepository is using rxjs library and Observables instead of promises.
 */
var ReactiveTreeRepository = (function (_super) {
    __extends(ReactiveTreeRepository, _super);
    // -------------------------------------------------------------------------
    // Constructor
    // -------------------------------------------------------------------------
    function ReactiveTreeRepository(repository) {
        _super.call(this, repository);
        this.repository = repository;
    }
    // -------------------------------------------------------------------------
    // Public Methods
    // -------------------------------------------------------------------------
    /**
     * Roots are entities that have no ancestors. Finds them all.
     */
    ReactiveTreeRepository.prototype.findRoots = function () {
        return this.repository.findRoots();
    };
    /**
     * Creates a query builder used to get descendants of the entities in a tree.
     */
    ReactiveTreeRepository.prototype.createDescendantsQueryBuilder = function (alias, closureTableAlias, entity) {
        return this.repository.createDescendantsQueryBuilder(alias, closureTableAlias, entity);
    };
    /**
     * Gets all children (descendants) of the given entity. Returns them all in a flat array.
     */
    ReactiveTreeRepository.prototype.findDescendants = function (entity) {
        return this.repository.findDescendants(entity);
    };
    /**
     * Gets all children (descendants) of the given entity. Returns them in a tree - nested into each other.
     */
    ReactiveTreeRepository.prototype.findDescendantsTree = function (entity) {
        return this.repository.findDescendantsTree(entity);
    };
    /**
     * Gets number of descendants of the entity.
     */
    ReactiveTreeRepository.prototype.countDescendants = function (entity) {
        return this.repository.countDescendants(entity);
    };
    /**
     * Creates a query builder used to get ancestors of the entities in the tree.
     */
    ReactiveTreeRepository.prototype.createAncestorsQueryBuilder = function (alias, closureTableAlias, entity) {
        return this.repository.createAncestorsQueryBuilder(alias, closureTableAlias, entity);
    };
    /**
     * Gets all parents (ancestors) of the given entity. Returns them all in a flat array.
     */
    ReactiveTreeRepository.prototype.findAncestors = function (entity) {
        return this.repository.findAncestors(entity);
    };
    /**
     * Gets all parents (ancestors) of the given entity. Returns them in a tree - nested into each other.
     */
    ReactiveTreeRepository.prototype.findAncestorsTree = function (entity) {
        return this.repository.findAncestorsTree(entity);
    };
    /**
     * Gets number of ancestors of the entity.
     */
    ReactiveTreeRepository.prototype.countAncestors = function (entity) {
        return this.repository.countAncestors(entity);
    };
    return ReactiveTreeRepository;
}(ReactiveRepository_1.ReactiveRepository));
exports.ReactiveTreeRepository = ReactiveTreeRepository;
//# sourceMappingURL=ReactiveTreeRepository.js.map