"use strict";
var fs = require("fs");
var path = require("path");
/**
 * Loads all exported classes from the given directory.
 * @internal
 */
var DirectoryExportedClassesLoader = (function () {
    function DirectoryExportedClassesLoader() {
    }
    // todo: this can be extracted into external module and used across all other modules
    // -------------------------------------------------------------------------
    // Public Methods
    // -------------------------------------------------------------------------
    /**
     * Imports all entities (makes them "require") from the given directories.
     */
    DirectoryExportedClassesLoader.prototype.importClassesFromDirectories = function (directories) {
        var allDirectories = directories.reduce(function (allDirs, dir) {
            return allDirs.concat(require("glob").sync(path.normalize(dir)));
        }, []);
        var requireAll = require("require-all");
        var filter = /(.*)\.js$/;
        var dirs = allDirectories
            .filter(function (directory) { return fs.existsSync(directory); })
            .map(function (directory) { return requireAll({ dirname: directory, filter: filter, recursive: true }); });
        return this.loadFileClasses(dirs, []);
    };
    // -------------------------------------------------------------------------
    // Private Methods
    // -------------------------------------------------------------------------
    DirectoryExportedClassesLoader.prototype.loadFileClasses = function (exported, allLoaded) {
        var _this = this;
        if (exported instanceof Function) {
            allLoaded.push(exported);
        }
        else if (exported instanceof Object) {
            Object.keys(exported).forEach(function (key) { return _this.loadFileClasses(exported[key], allLoaded); });
        }
        else if (exported instanceof Array) {
            exported.forEach(function (i) { return _this.loadFileClasses(i, allLoaded); });
        }
        return allLoaded;
    };
    return DirectoryExportedClassesLoader;
}());
exports.DirectoryExportedClassesLoader = DirectoryExportedClassesLoader;
function importClassesFromDirectories(directories) {
    var loader = new DirectoryExportedClassesLoader();
    return loader.importClassesFromDirectories(directories);
}
exports.importClassesFromDirectories = importClassesFromDirectories;
//# sourceMappingURL=DirectoryExportedClassesLoader.js.map